local L = Capitalist.Locals

function Capitalist:BuildOptions()
	self.options = {
		type = "group",
		args = {
			general = {
				name = L["General options"],
				type = "group",
				order = 1,
				args = {
					minProfit = {
						name = L["Minimal profit"],
						order = 1,
						desc = L["How much you want to gain at minimum from each scroll (price is simply added to material cost)."],
						type = "input",
						set = function(info, val)
								self.db.profile.minProfit = (tonumber(val) or 0) * 10000
							  end,
						get = function(info)
								return ""..self.db.profile.minProfit / 10000
							  end,
					},
					margin = {
						name = L["Price margin"],
						order = 3,
						desc = L["The increase (in percent) in price, if there is no or very expensive competition."],
						type = "input",
						set = function(info, val)
								self.db.profile.margin = tonumber(val) or 0
							  end,
						get = function(info)
								return ""..self.db.profile.margin
							  end,
					},
					minMargin = {
						name = L["Minimal increase"],
						order = 5,
						desc = L["How much (in gold) the price should increase at minimum if there is no or very expensive competition."],
						type = "input",
						set = function(info, val)
								self.db.profile.minMargin = (tonumber(val) or 0) * 10000
							  end,
						get = function(info)
								return ""..self.db.profile.minMargin / 10000
							  end,
					},
					maxMargin = {
						name = L["Maximal increase"],
						order = 7,
						desc = L["How much (in gold) the price should increase at maximum if there is no or very expensive competition."],
						type = "input",
						set = function(info, val)
								self.db.profile.maxMargin = (tonumber(val) or 0) * 10000
							  end,
						get = function(info)
								return ""..self.db.profile.maxMargin / 10000
							  end,
					},
					showByDefault = {
						name = L["Show by default"],
						order = 2,
						desc = L["Automatically opens Capitalist when you enter the Auction House"],
						type = "toggle",
						set = function(info, val)
								self.db.profile.showByDefault = val
							  end,
						get = function(info)
								return self.db.profile.showByDefault
							  end,
					},
					Northrend = {
						name = L["Northrend"],
						order = 4,
						desc = L["If checked, enchants using Northrend reagents will be produced"],
						type = "toggle",
						set = function(info, val)
								self.db.profile.filters.global.Northrend = val
								self:ApplyFilters()
							  end,
						get = function(info)
								return self.db.profile.filters.global.Northrend
							  end,
					},
					BurningCrusade = {
						name = L["Burning Crusade"],
						order = 6,
						desc = L["If checked, enchants using Burning Crusade reagents will be produced"],
						type = "toggle",
						set = function(info, val)
								self.db.profile.filters.global.BurningCrusade = val
								self:ApplyFilters()
							  end,
						get = function(info)
								return self.db.profile.filters.global.BurningCrusade
							  end,
					},
					Classic = {
						name = L["Classic"],
						order = 8,
						desc = L["If checked, enchants using Classic reagents will be produced"],
						type = "toggle",
						set = function(info, val)
								self.db.profile.filters.global.Classic = val
								self:ApplyFilters()
							  end,
						get = function(info)
								return self.db.profile.filters.global.Classic
							  end,
					},
				}
			},
			recipeFilters = {
				name = L["Scroll Filters"],
				type = "group",
				order = 2,
				args = {}
			},
			reagentPrices = {
				name = L["Reagent Prices"],
				type = "group",
				order = 3,
				args = {}
			},
			scrollCount = {
				name = L["Scroll Count"],
				type = "group",
				order = 4,
				args = {}
			},
			createdScrolls = {
				name = L["Created Scrolls"],
				type = "group",
				order = 5,
				args = {}
			},
		}
	}
	
	self:UpdateFilterOptions()
	self:UpdateStatistics()
	
	LibStub("AceConfig-3.0"):RegisterOptionsTable("Capitalist", self.options)
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions("Capitalist")
	self:RegisterChatCommand("Capitalist", function(input) Capitalist:HandleSlashCommand(input) end)
	self:RegisterChatCommand("cap", function(input) Capitalist:HandleSlashCommand(input) end)
end

function Capitalist:UpdateFilterOptions()
	local t

	-- populate scroll filters
	self.options.args.recipeFilters.args = {}
	t = self.options.args.recipeFilters.args
	for recipe, data in pairs(self.db.profile.recipes) do
		if (data.isUsed == true) then
			t[recipe] = {
				name = L.stripSkillName(recipe),
				desc = data.description,
				type = "toggle",
				set = function(info, val)
						data.isFiltered = not val
						self:ApplyFilters()
					  end,
				get = function(info)
						return not data.isFiltered
					  end
			}
		end
	end
	
	-- add scroll filter "all"
	if (self.allScrollsFilter == nil) then
		self.allScrollsFilter = true
	end
	t["all"] = {
		name = L["all scrolls"],
		desc = L["enable or disable all scrolls"],
		type = "toggle",
		order = 1,
		set = function(info, val)
					Capitalist.allScrollsFilter = val
					for recipe, data in pairs(self.db.profile.recipes) do
						if (data.isUsed == true) then
							data.isFiltered = not val
						end
					end
					self:ApplyFilters()
				end,
		get = function(info)
					return Capitalist.allScrollsFilter
				end
	}

	-- populate reagent prices
	self.options.args.reagentPrices.args = {}
	t = self.options.args.reagentPrices.args
	for reagent, data in pairs(self.db.profile.reagents) do
		if (data.isUsed == true) then
			t[reagent] = {
				name = reagent,
				desc = string.format(L["Set the price of %s in gold"], reagent),
				type = "range",
				min = 0,
				max = 40,
				step = 0.01,
				bigStep = 1,
				order = data.itemId,
				set = function(info, val)
						self.db.profile.reagents[reagent].price = val
					  end,
				get = function(info)
						return self.db.profile.reagents[reagent].price
					  end
			}
		end
	end
	
	-- populate scroll count
	self.options.args.scrollCount.args = {}
	t = self.options.args.scrollCount.args
	for recipe, data in pairs(self.db.profile.recipes) do
		if (data.isUsed == true) then
			t[recipe] = {
				name = L.stripSkillName(recipe),
				desc = data.description,
				type = "range",
				min = 0,
				max = 40,
				step = 1,
				set = function(info, val)
						self.db.profile.recipes[recipe].scrollCount = val
					  end,
				get = function(info, val)
						return self.db.profile.recipes[recipe].scrollCount
					  end
			}
		end
	end
	
	self:UpdateStatistics()
end

function Capitalist:UpdateStatistics()
	local t

	-- populate created scrolls
	self.options.args.createdScrolls.args = {}
	t = self.options.args.createdScrolls.args
	for recipe, data in pairs(self.db.profile.recipes) do
		if (data.isUsed == true and data.numCreated > 0) then
			t[recipe] = {
				name = data.numCreated.."x "..L.stripSkillName(recipe),
				type = "description",
				order = -data.numCreated,
			}
		end
	end
end
